/**
 * Based on MySensors
 * 
 * DESCRIPTION
 * Sketch showing how to measure light level using a photo-resistor
 *
 * Version 1.0 13.06.2017 by Oliver Hilsky
 */


// library settings
//#define MY_NODE_ID 11
#define MY_RADIO_NRF24
#define MY_DEBUG    // Enables debug messages in the serial log
#define MY_DEBUG_VERBOSE_SIGNING //!< Enable signing related debug prints to serial monitor
#define MY_BAUD_RATE  9600 // Sets the serial baud rate for console and serial gateway
#define MY_SIGNING_SOFT // Enables software signing
#define MY_SIGNING_REQUEST_SIGNATURES // Always request signing from gateway
#define MY_SIGNING_SOFT_RANDOMSEED_PIN 7 // floating pin for randomness
//#define MY_SIGNING_NODE_WHITELISTING {{.nodeId = GATEWAY_ADDRESS,.serial = {...}}} // gateway addres if you want to use whitelisting (node only works with messages from this one gateway)

#include <SPI.h>
#include <Wire.h>
#include <MyConfig.h>
#include <MySensors.h>
#include <Vcc.h>

#define BATTERYVOLTAGE 0
#define LIGHTLEVEL 1
#define LIGHT_SENSOR_ANALOG_PIN A1
#define MESSAGEWAIT 100

const float VccMin   = 1.9;           // Minimum expected Vcc level, in Volts.
const float VccMax   = 3.3;           // Maximum expected Vcc level, in Volts.
const float VccCorrection = 1 / 1 ; // Measured Vcc by multimeter divided by reported Vcc

float BatteryVoltage = 0.0;
float PreviousBatteryVoltage = 0.0;
int LightLevel = 0;
int PreviousLightLevel = 0;
unsigned long SLEEP_TIME = 300000; // Sleep time between reads (in milliseconds) - 5 minutes

// instantiate classes
Vcc vcc(VccCorrection);
MyMessage BatMsg(BATTERYVOLTAGE, V_VOLTAGE);
MyMessage LightMsg(LIGHTLEVEL, V_LIGHT_LEVEL);



void presentation()
{
  // Send the sketch version information to the gateway and Controller
  sendSketchInfo("Light Sensor", "1.0 13062017");
  wait(MESSAGEWAIT);
  // Register all sensors to gateway (they will be created as child devices)
  present(BATTERYVOLTAGE, S_MULTIMETER);
  wait(MESSAGEWAIT);
  present(LIGHTLEVEL, S_LIGHT_LEVEL);
}


// the setup function runs once when you press reset or power the board
void setup() {
  pinMode(LIGHT_SENSOR_ANALOG_PIN, INPUT);
  LightLevel = (1023 - analogRead(LIGHT_SENSOR_ANALOG_PIN)) / 10.23;
  PreviousBatteryVoltage = 20.0;
  PreviousLightLevel = 0;
}


void loop()
{
  BatteryVoltage = vcc.Read_Volts();
  LightLevel = (1023 - analogRead(LIGHT_SENSOR_ANALOG_PIN)) / 10.23;

  Serial.println(LightLevel);

  if (BatteryVoltage != PreviousBatteryVoltage) {
    send(BatMsg.set(BatteryVoltage, 3));
    PreviousBatteryVoltage = BatteryVoltage;
  }
  
  sleep(MESSAGEWAIT);

  if (LightLevel != PreviousLightLevel) {
    send(LightMsg.set(LightLevel));
    PreviousLightLevel = LightLevel;
  }

  sleep(SLEEP_TIME);
}
